@@ -18,6 +18,8 @@
 #'   for examples. \code{\link{rec_pattern}} is a convenient function to
 #'   create recode strings for grouping variables.
 #' @param as.num Logical, if \code{TRUE}, return value will be numeric, not a factor.
+#' @param to.factor Logical, alias for \code{as.num}. If \code{TRUE}, return value
+#'   will be a factor, not numeric.
 #' @param var.label Optional string, to set variable label attribute for the
 #'   returned variable (see vignette \href{https://cran.r-project.org/package=sjlabelled/vignettes/intro_sjlabelled.html}{Labelled Data and the sjlabelled-Package}).
 #'   If \code{NULL} (default), variable label attribute of \code{x} will
@@ -42,13 +44,11 @@
 #'     \item grouped variables (\code{group_var()}) will be suffixed with \code{"_gr"}
 #'     \item standardized variables (\code{std()}) will be suffixed with \code{"_z"}
 #'     \item centered variables (\code{center()}) will be suffixed with \code{"_c"}
-#'     \item de-meaned variables (\code{de_mean()}) will be suffixed with \code{"_dm"}
-#'     \item grouped-meaned variables (\code{de_mean()}) will be suffixed with \code{"_gm"}
 #'   }
 #'   If \code{suffix = ""} and \code{append = TRUE}, existing variables that
 #'   have been recoded/transformed will be overwritten.
 #'
-#' @inheritParams to_factor
+#' @inheritParams to_dummy
 #'
 #' @return \code{x} with recoded categories. If \code{x} is a data frame,
 #'   for \code{append = TRUE}, \code{x} including the recoded variables
@@ -179,20 +179,22 @@
 #' p <- function(x) min(x, na.rm = TRUE) > 0 && max(x, na.rm = TRUE) < 5
 #' out <- rec_if(efc, predicate = p, rec = "1:3=1;4=2;else=copy")
 #' head(out)
-#' @importFrom insight print_color
 #' @export
-rec <- function(x, ..., rec, as.num = TRUE, var.label = NULL, val.labels = NULL, append = TRUE, suffix = "_r") {
+rec <- function(x, ..., rec, as.num = TRUE, var.label = NULL, val.labels = NULL, append = TRUE, suffix = "_r", to.factor = !as.num) {
   UseMethod("rec")
 }
 
 
-#' @importFrom dplyr quos
 #' @export
-rec.default <- function(x, ..., rec, as.num = TRUE, var.label = NULL, val.labels = NULL, append = TRUE, suffix = "_r") {
+rec.default <- function(x, ..., rec, as.num = TRUE, var.label = NULL, val.labels = NULL, append = TRUE, suffix = "_r", to.factor = !as.num) {
 
   # evaluate arguments, generate data
   .dat <- get_dot_data(x, dplyr::quos(...))
 
+  if (!missing(to.factor)) {
+    as.num <- !to.factor
+  }
+
   rec_core_fun(
     x = x,
     .dat = .dat,
@@ -206,13 +208,15 @@ rec.default <- function(x, ..., rec, as.num = TRUE, var.label = NULL, val.labels
 }
 
 
-#' @importFrom dplyr bind_cols select quos
-#' @importFrom purrr map
 #' @export
-rec.mids <- function(x, ..., rec, as.num = TRUE, var.label = NULL, val.labels = NULL, append = TRUE, suffix = "_r") {
+rec.mids <- function(x, ..., rec, as.num = TRUE, var.label = NULL, val.labels = NULL, append = TRUE, suffix = "_r", to.factor = !as.num) {
   vars <- dplyr::quos(...)
   ndf <- prepare_mids_recode(x)
 
+  if (!missing(to.factor)) {
+    as.num <- !to.factor
+  }
+
   # select variable and compute rowsums. add this variable
   # to each imputed
 
@@ -239,14 +243,16 @@ rec.mids <- function(x, ..., rec, as.num = TRUE, var.label = NULL, val.labels =
 }
 
 
-#' @importFrom dplyr select_if
 #' @rdname rec
 #' @export
-rec_if <- function(x, predicate, rec, as.num = TRUE, var.label = NULL, val.labels = NULL, append = TRUE, suffix = "_r") {
+rec_if <- function(x, predicate, rec, as.num = TRUE, var.label = NULL, val.labels = NULL, append = TRUE, suffix = "_r", to.factor = !as.num) {
 
   # select variables that match logical conditions
   .dat <- dplyr::select_if(x, .predicate = predicate)
 
+  if (!missing(to.factor)) {
+    as.num <- !to.factor
+  }
 
   # if no variable matches the condition specified
   # in predicate, return original data
@@ -309,8 +315,6 @@ rec_core_fun <- function(x, .dat, rec, as.num = TRUE, var.label = NULL, val.labe
 }
 
 
-#' @importFrom stats na.omit
-#' @importFrom sjlabelled drop_labels get_na get_label get_labels set_label set_labels
 rec_helper <- function(x, recodes, as.num, var.label, val.labels) {
   # retrieve variable label
   if (is.null(var.label))
@@ -367,8 +371,8 @@ rec_helper <- function(x, recodes, as.num, var.label, val.labels) {
 
 
   # retrieve min and max values
-  min_val <- min(x, na.rm = T)
-  max_val <- max(x, na.rm = T)
+  min_val <- min(x, na.rm = TRUE)
+  max_val <- max(x, na.rm = TRUE)
 
   # do we have special recode-token?
   if (recodes_reversed) {
@@ -430,8 +434,8 @@ rec_helper <- function(x, recodes, as.num, var.label, val.labels) {
   rec_string <- gsub(" ", "", rec_string, useBytes = TRUE, fixed = TRUE)
 
   # remove line breaks
-  rec_string <- gsub("\n", "", rec_string, useBytes = TRUE, fixed = F)
-  rec_string <- gsub("\r", "", rec_string, useBytes = TRUE, fixed = F)
+  rec_string <- gsub("\n", "", rec_string, useBytes = TRUE, fixed = FALSE)
+  rec_string <- gsub("\r", "", rec_string, useBytes = TRUE, fixed = FALSE)
 
   # replace min and max placeholders
   rec_string <- gsub("(\\blo\\b)(.*)=(.*)", paste0(as.character(min_val), "\\2=\\3"), rec_string, useBytes = TRUE, perl = TRUE)
@@ -452,7 +456,7 @@ rec_helper <- function(x, recodes, as.num, var.label, val.labels) {
 
   # found any errors in syntax?
   if (!is.null(correct_syntax)) {
-    stop(sprintf("?Syntax error in argument \"%s\"", paste(correct_syntax, collapse = "=")), call. = F)
+    stop(sprintf("?Syntax error in argument \"%s\"", paste(correct_syntax, collapse = "=")), call. = FALSE)
   }
 
 
@@ -512,11 +516,15 @@ rec_helper <- function(x, recodes, as.num, var.label, val.labels) {
       } else if (length(grep(":", ovs, fixed = TRUE)) > 0) {
         # this value indicates a range of values to be recoded, because
         # we have found a colon. now copy from and to values from range
-        from <- suppressWarnings(as.numeric(unlist(strsplit(ovs, ":", fixed = T))[1]))
-        to <- suppressWarnings(as.numeric(unlist(strsplit(ovs, ":", fixed = T))[2]))
+        from <- suppressWarnings(as.numeric(unlist(strsplit(ovs, ":", fixed = TRUE))[1]))
+        to <- suppressWarnings(as.numeric(unlist(strsplit(ovs, ":", fixed = TRUE))[2]))
         # check for valid range values
         if (is.na(from) || is.na(to)) {
-          stop(sprintf("?Syntax error in argument \"%s\"", ovs), call. = F)
+          stop(sprintf("?Syntax error in argument \"%s\"", ovs), call. = FALSE)
+        }
+        # to lower than from?
+        if (from > to) {
+          stop(sprintf("?Syntax error in recode range from %g to %g.", from, to), call. = FALSE)
         }
         # for floating point range, we keep the range
         if (with_dec)
@@ -568,8 +576,8 @@ rec_helper <- function(x, recodes, as.num, var.label, val.labels) {
       } else if (is.character(old_val[k]) && with_dec) {
         # this value indicates a range of values to be recoded, because
         # we have found a colon. now copy from and to values from range
-        from <- suppressWarnings(as.numeric(unlist(strsplit(old_val[k], ":", fixed = T))[1]))
-        to <- suppressWarnings(as.numeric(unlist(strsplit(old_val[k], ":", fixed = T))[2]))
+        from <- suppressWarnings(as.numeric(unlist(strsplit(old_val[k], ":", fixed = TRUE))[1]))
+        to <- suppressWarnings(as.numeric(unlist(strsplit(old_val[k], ":", fixed = TRUE))[2]))
         # if old_val is a character, we assume we have a double with decimal
         # points and want to recode a range
         new_var[which(x >= from & x <= to)] <- new_val
